import { base16, base64, base58 } from '@scure/base';
export { bech32 } from '@scure/base';
export const stripPrefix = (prefix, str) => str.startsWith(prefix) ? str.slice(prefix.length) : str;
const isHexRegex = /^(?:0x)?[0-9a-fA-F]+$/;
export const hex = {
    valid: (input) => isHexRegex.test(input),
    decode: (input) => base16.decode(stripPrefix("0x", input).toUpperCase()),
    encode: (input, prefix = false) => {
        input = typeof input === "string" ? bytes.encode(input) : input;
        return (prefix ? "0x" : "") + base16.encode(input).toLowerCase();
    }
};
// regex string to check if the input could possibly be base64 encoded.
// WARNING: There are clear text strings that are NOT base64 encoded that will pass this check.
const isB64Regex = /^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$/;
export const b64 = {
    valid: (input) => isB64Regex.test(input),
    decode: base64.decode,
    encode: (input) => base64.encode(typeof input === "string" ? bytes.encode(input) : input)
};
export const b58 = {
    decode: base58.decode,
    encode: (input) => base58.encode(typeof input === "string" ? bytes.encode(input) : input),
};
export const bignum = {
    decode: (input) => BigInt(input),
    encode: (input, prefix = false) => (prefix ? "0x" : "") + input.toString(16)
};
export const bytes = {
    encode: (value) => typeof value === "bigint"
        ? bytes.encode(bignum.encode(value))
        : (new TextEncoder()).encode(value),
    decode: (value) => (new TextDecoder()).decode(value),
    equals: (lhs, rhs) => lhs.length === rhs.length && lhs.every((v, i) => v === rhs[i]),
    zpad: (arr, length) => bytes.concat(new Uint8Array(length - arr.length), arr),
    concat: (...args) => {
        const length = args.reduce((acc, curr) => acc + curr.length, 0);
        const result = new Uint8Array(length);
        let offset = 0;
        args.forEach((arg) => {
            result.set(arg, offset);
            offset += arg.length;
        });
        return result;
    }
};
//# sourceMappingURL=encoding.js.map